.. py:currentmodule:: rubin_sim

.. _rubin_sim.index:

#########
rubin_sim
#########

:doc:`Overview <../index>`

:doc:`Table of contents <../toc>`


==========
Python API
==========

.. _rubin_sim.utils api:

:doc:`rubin_sim.utils api <../rs_utils/index>`
==============================================
.. automodapi:: rubin_sim.utils
   :no-main-docstr:
   :no-inheritance-diagram:

.. _rubin_sim.data api:

:doc:`rubin_sim.data api <../rs_data/index>`
============================================
.. automodapi:: rubin_sim.data
   :no-main-docstr:
   :no-inheritance-diagram:


.. _rubin_sim.phot_utils api:

:doc:`rubin_sim.phot_utils api <../rs_phot_utils/index>`
======================================================
.. automodapi:: rubin_sim.phot_utils
   :no-main-docstr:
   :no-inheritance-diagram:


.. _rubin_sim.satellite_constellations api:

:doc:`rubin_sim.satellite_constellations api <../rs_satellite_constellations/index>`
======================================================
.. automodapi:: rubin_sim.satellite_constellations
   :no-main-docstr:
   :no-inheritance-diagram:

.. _rubin_sim.selfcal api:

:doc:`rubin_sim.selfcal api <../rs_selfcal/index>`
======================================================
.. automodapi:: rubin_sim.selfcal
   :no-main-docstr:
   :no-inheritance-diagram:

.. _rubin_sim.site_models api:

:doc:`rubin_sim.site_models api <../rs_site_models/index>`
==========================================================
.. automodapi:: rubin_sim.site_models
   :no-main-docstr:
   :no-inheritance-diagram:

.. _rubin_sim.skybrightness api:

:doc:`rubin_sim.skybrightness api <../rs_skybrightness/index>`
==============================================================
.. automodapi:: rubin_sim.skybrightness
   :no-main-docstr:
   :no-inheritance-diagram:

.. _rubin_sim.skybrightness_pre api:

:doc:`rubin_sim.skybrightness_pre api <../rs_skybrightness_pre/index>`
======================================================================
.. automodapi:: rubin_sim.skybrightness_pre
   :no-main-docstr:
   :no-inheritance-diagram:

.. _rubin_sim.scheduler api:

:doc:`rubin_sim.scheduler api <../rs_scheduler/index>`
======================================================
.. automodapi:: rubin_sim.scheduler
   :no-main-docstr:
   :no-inheritance-diagram:

.. automodapi:: rubin_sim.scheduler.schedulers
   :no-main-docstr:
   :no-inheritance-diagram:

.. automodapi:: rubin_sim.scheduler.surveys
   :no-main-docstr:
   :no-inheritance-diagram:

.. automodapi:: rubin_sim.scheduler.basis_functions
   :no-main-docstr:
   :no-inheritance-diagram:

.. automodapi:: rubin_sim.scheduler.features
   :no-main-docstr:
   :no-inheritance-diagram:

.. automodapi:: rubin_sim.scheduler.detailers
   :no-main-docstr:
   :no-inheritance-diagram:

.. automodapi:: rubin_sim.scheduler.model_observatory
   :no-main-docstr:
   :no-inheritance-diagram:

.. automodapi:: rubin_sim.scheduler.utils
   :no-main-docstr:
   :no-inheritance-diagram:


.. _rubin_sim.movingObjects api:

:doc:`rubin_sim.movingObjects api <../rs_moving_objects/index>`
==============================================================
.. automodapi:: rubin_sim.moving_objects
   :no-main-docstr:
   :no-inheritance-diagram:


.. _rubin_sim.maf api:

:doc:`rubin_sim.maf api <../rs_maf/index>`
==========================================
.. automodapi:: rubin_sim.maf.batches
   :no-main-docstr:
   :no-inheritance-diagram:

.. automodapi:: rubin_sim.maf.metrics
   :no-main-docstr:
   :no-inheritance-diagram:

.. automodapi:: rubin_sim.maf.maf_contrib
   :no-main-docstr:
   :no-inheritance-diagram:

.. automodapi:: rubin_sim.maf.slicers
   :no-main-docstr:
   :no-inheritance-diagram:

.. automodapi:: rubin_sim.maf.db
   :no-main-docstr:
   :no-inheritance-diagram:

.. automodapi:: rubin_sim.maf.maps
   :no-main-docstr:
   :no-inheritance-diagram:

.. automodapi:: rubin_sim.maf.stackers
   :no-main-docstr:
   :no-inheritance-diagram:

.. automodapi:: rubin_sim.maf.plots
   :no-main-docstr:
   :no-inheritance-diagram:

.. automodapi:: rubin_sim.maf.metric_bundles
   :no-main-docstr:
   :no-inheritance-diagram:

.. automodapi:: rubin_sim.maf.run_comparison
   :no-main-docstr:
   :no-inheritance-diagram:

.. automodapi:: rubin_sim.maf.utils
   :no-main-docstr:
   :no-inheritance-diagram:

.. automodapi:: rubin_sim.maf.web
   :no-main-docstr:
   :no-inheritance-diagram:


======
Search
======

* :ref:`search`
